matminer.figrecipes.tests package — matminer 0.5.9 documentation

# matminer.figrecipes.tests package

## Submodules

## matminer.figrecipes.tests.test_plots module

PlotlyFig testing. Most tests are run by comparing generated Plotly figures with pre-generated json files. Some are just ensuring Plotly does not throw errors.

class `matminer.figrecipes.tests.test_plots.` `PlotlyFigTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `fopen`(fname)
  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_bar`()
  `test_heatmap_basic`()
  `test_heatmap_df`()
  `test_histogram`()
  `test_parallel_coordinates`()
  `test_scatter_matrix`()
  `test_triangle`()
  `test_violin`()
  `test_xy`()

`matminer.figrecipes.tests.test_plots.` `refresh_json`(open_plots=False)

  For developer use. Refresh the json files and open plots to see if they look good. Use this function to set the current PlotlyFig build outputs as the true values of the tests.

  Args:
    open_plots (bool): If True, opens all plots generated. Useful if you

      want to check the current build outputs to make sure they look good. If False, just generates the json files and quits.

## Module contents